An agent did work on this project.

- See what it did
- Update the python bindings and streaming server if needed
- Bump minor version
- Update CHANGELOG.md and README.md and docs/
- Commit and push

$ARGUMENTS
